@@ -13,9 +13,9 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 # ============================================================================
-import unittest
 
-import mock
+import unittest
+from unittest import mock
 
 from attributecode import api
 from attributecode import ERROR
