@@ -2,7 +2,7 @@
 # -*- coding: utf8 -*-
 
 # ============================================================================
-#  Copyright (c) 2017 nexB Inc. http://www.nexb.com/ - All rights reserved.
+#  Copyright (c) nexB Inc. http://www.nexb.com/ - All rights reserved.
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
@@ -14,10 +14,6 @@
 #  limitations under the License.
 # ============================================================================
 
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import logging
 import ntpath
 import os
@@ -28,17 +24,14 @@ import sys
 import tempfile
 import zipfile
 
-
 from attributecode.util import add_unc
 from attributecode.util import to_posix
 
-
 logger = logging.getLogger(__name__)
 handler = logging.StreamHandler()
 handler.setLevel(logging.DEBUG)
 logger.addHandler(handler)
 
-
 TESTDATA_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'testdata')
 
 on_windows = 'win32' in sys.platform
@@ -57,6 +50,7 @@ def get_test_loc(path, must_exists=True):
         assert os.path.exists(path)
     return path
 
+
 def create_dir(location):
     """
     Create directory or directory tree at location, ensuring it is readable
